@@ -20,8 +20,9 @@
 #
 #"""
 
-__authors__ = 'Michele Mattioni <mattioni@ebi.ac.uk>'
-__version__ = '0.6.2'
+__authors__ = ['Michele Mattioni <mattioni@ebi.ac.uk>', 
+               'Uri Cohen <uri.cohen@alice.nc.huji.ac.il>']
+__version__ = '0.7.0'
 
 
 import os
